import { NextRequest } from "next/server";
import { NextResponse } from "next/server";
import { IAfOptions } from "./types";

/**
 *
 * @param request NextRequest
 * @param loginPage login page
 * @param redirectToIfValid redirect to if token valid and user come to login
 * @returns
 */
export async function accessTokenOnly(
  request: NextRequest,
  afAuthOptions: IAfOptions,
  loginPage?: string,
  redirectToIfValid?: string
) {
  if (request.nextUrl.pathname.startsWith("/api/afAuth")) {
    return NextResponse.next();
  }
  if (
    !request.nextUrl.pathname.startsWith(loginPage || afAuthOptions.logInPage)
  ) {
    let accessCookie = request.cookies.get("access")?.value;
    if (accessCookie) {
      return AddBearerToken(accessCookie, request);
    } else {
      const response = NextResponse.next();
      response.cookies.set({
        name: "access",
        value: "",
        path: "/",
        secure: true,
        httpOnly: true,
        expires: new Date(0),
        sameSite: "strict",
      });

      if (!request.nextUrl.pathname.includes(afAuthOptions.apiBaseUrl)) {
        return NextResponse.redirect(
          new URL(loginPage || afAuthOptions.logInPage, request.url)
        );
      } else if (request.nextUrl.pathname.includes(afAuthOptions.apiBaseUrl)) {
        return NextResponse.next();
      }
    }
  } else if (
    request.nextUrl.pathname.startsWith(loginPage || afAuthOptions.logInPage)
  ) {
    let accessCookie = request.cookies.get("access")?.value;
    if (accessCookie) {
      return NextResponse.redirect(
        new URL(redirectToIfValid || afAuthOptions.redirectToPage, request.url)
      );
    }
  } else {
    return NextResponse.next();
  }
}

function AddBearerToken(accessCookie: string, request: NextRequest) {
  const requestHeaders = new Headers(request.headers);
  requestHeaders.set("Authorization", `Bearer ${accessCookie}`);
  return NextResponse.next({
    request: {
      headers: requestHeaders,
    },
  });
}
